@@ -168,23 +168,23 @@ predict.multinomial_naive_bayes <- function (object, newdata = NULL, type = c("c
 print.multinomial_naive_bayes <- function (x, ...) {
 
     model <- "Multinomial Naive Bayes"
-    n_char <- getOption("width")
-    str_left_right <- paste0(rep("=", floor((n_char - nchar(model)) / 2)),
+    n_char <- getOption("width") - 3
+    str_left_right <- paste0(rep("=", ceiling((n_char - nchar(model)) / 2)),
                              collapse = "")
     str_full <- paste0(str_left_right, " ", model, " ",
                        ifelse(n_char %% 2 != 0, "=", ""), str_left_right)
     len <- nchar(str_full)
     l <- paste0(rep("-", len), collapse = "")
     cat("\n")
-    cat(str_full, "\n", "\n", "Call:", "\n")
+    cat(str_full, "\n", "\n", "Call:", "\n", sep = "")
     print(x$call)
     cat("\n")
     cat(l, "\n", "\n")
-    cat( "Laplace smoothing:", x$laplace)
+    cat("Laplace smoothing: ", x$laplace, sep = "")
     cat("\n")
     cat("\n")
     cat(l, "\n", "\n")
-    cat(" A priori probabilities:", "\n")
+    cat("A priori probabilities:", "\n")
     print(x$prior)
     cat("\n")
     cat(l, "\n", "\n")
@@ -213,9 +213,10 @@ coef.multinomial_naive_bayes  <- function(object, ...) {
 }
 
 summary.multinomial_naive_bayes <- function(object, ...) {
+
     model <- "Multinomial Naive Bayes"
-    n_char <- getOption("width")
-    str_left_right <- paste0(rep("=", floor((n_char - nchar(model)) / 2)),
+    n_char <- getOption("width") - 3
+    str_left_right <- paste0(rep("=", ceiling((n_char - nchar(model)) / 2)),
                              collapse = "")
     str_full <- paste0(str_left_right, " ", model, " ",
                        ifelse(n_char %% 2 != 0, "=", ""), str_left_right)
