@@ -195,27 +195,27 @@ predict.poisson_naive_bayes <- function (object, newdata = NULL, type = c("class
 print.poisson_naive_bayes <- function (x, ...) {
 
     model <- "Poisson Naive Bayes"
-    n_char <- getOption("width")
-    str_left_right <- paste0(rep("=", floor((n_char - nchar(model)) / 2)),
+    n_char <- getOption("width") - 3
+    str_left_right <- paste0(rep("=", ceiling((n_char - nchar(model)) / 2)),
                              collapse = "")
     str_full <- paste0(str_left_right, " ", model, " ",
                        ifelse(n_char %% 2 != 0, "=", ""), str_left_right)
     len <- nchar(str_full)
     l <- paste0(rep("-", len), collapse = "")
     cat("\n")
-    cat(str_full, "\n", "\n", "Call:", "\n")
+    cat(str_full, "\n", "\n", "Call:", "\n", sep = "")
     print(x$call)
     cat("\n")
     cat(l, "\n", "\n")
-    cat( "Laplace smoothing:", x$laplace)
+    cat("Laplace smoothing:", x$laplace)
     cat("\n")
     cat("\n")
     cat(l, "\n", "\n")
-    cat(" A priori probabilities:", "\n")
+    cat("A priori probabilities:", "\n")
     print(x$prior)
     cat("\n")
     cat(l, "\n", "\n")
-    cat(" Tables:", "\n")
+    cat("Tables:", "\n")
     tabs <- get_tables(x)
     n <- length(tabs)
     indices <- seq_len(min(5,n))
@@ -247,9 +247,10 @@ coef.poisson_naive_bayes  <- function(object, ...) {
 }
 
 summary.poisson_naive_bayes <- function(object, ...) {
+
     model <- "Poisson Naive Bayes"
-    n_char <- getOption("width")
-    str_left_right <- paste0(rep("=", floor((n_char - nchar(model)) / 2)),
+    n_char <- getOption("width") - 3
+    str_left_right <- paste0(rep("=", ceiling((n_char - nchar(model)) / 2)),
                              collapse = "")
     str_full <- paste0(str_left_right, " ", model, " ",
                        ifelse(n_char %% 2 != 0, "=", ""), str_left_right)
